@@ -130,19 +130,13 @@ async fn collect_vpc(
         collect!(aws::network_acls, "Network ACLs");
         collect!(aws::vpc_peering_connections, "VPC Peering Connections");
         collect!(aws::vpc_endpoints, "VPC Endpoints");
-
-        // let nat_gateways = get_all_nat_gateways_from_vpc(client, vpc).await?;
-        // resources.extend(nat_gateways);
-
-        // let security_groups = get_all_security_groups_from_vpc(client, vpc).await?;
-        // resources.extend(security_groups);
-
-        // let vpn_connections = get_all_vpn_connections_from_vpc(client, vpc).await?;
-        // resources.extend(vpn_connections);
-
-        // let vpn_gateways = get_all_vpn_gateways_from_vpc(client, &vpc).await?;
-        // resources.extend(vpn_gateways);
+        collect!(aws::nat_gateways, "NAT Gateways");
+        collect!(aws::security_groups, "Security Groups");
+        collect!(aws::vpn_connections, "VPN Connections");
+        collect!(aws::vpn_gateways, "VPN Gateways");
+        collect!(aws::network_interfaces, "Network Interfaces");
     }
+
     ptree.end_child();
     Ok(())
 }
